@@ -1,11 +1,11 @@
 """
-Copyright 2019 Cognitive Scale, Inc. All Rights Reserved.
+Copyright 2021 Cognitive Scale, Inc. All Rights Reserved.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+  https://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,9 +19,6 @@ import json
 from .utils import get_cortex_profile
 from .exceptions import BadTokenException
 
-DEFAULT_API_ENDPOINT = 'https://api.cortex.insights.ai'
-
-
 class CortexEnv:
     """
     Sets environment variables for Cortex.
@@ -34,7 +31,7 @@ class CortexEnv:
         cortexConfig = config or json.loads(os.getenv('CORTEX_PERSONAL_ACCESS_CONFIG', json.dumps(profile)))
         if not cortexToken and not cortexConfig:
             raise BadTokenException(
-                'Your Cortex credentials cannot be retrieved. For more information, go to Cortex Docs > Cortex Tools > Access')
+                'Your Cortex credentials cannot be retrieved. Check your profile settings with `cortex configure`.')
 
         self.api_endpoint = api_endpoint or cortexConfig.get('url')
         self.token = cortexToken
@@ -46,8 +43,6 @@ class CortexEnv:
         """
         gets the token from either the cortex_token env variable or the profile's token.
         if cortex_token and both cortex_profile are falsey, then cortexToken will be None
-
-        :param profile: configured cortex profile from the local machine
         """
         cortexToken = CortexEnv.get_cortex_token() or CortexEnv.get_cortex_profile().get('token')
         return cortexToken
